Class: Google::Apis::NetworksecurityV1::AuthzPolicyAuthzRuleTo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

Describes properties of one or more targets of a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleTo

Returns a new instance of AuthzPolicyAuthzRuleTo.



636
637
638
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#not_operationsArray<Google::Apis::NetworksecurityV1::AuthzPolicyAuthzRuleToRequestOperation>

Optional. Describes the negated properties of the targets of a request. Matches requests for operations that do not match the criteria specified in this field. At least one of operations or notOperations must be specified. Corresponds to the JSON property notOperations



624
625
626
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 624

def not_operations
  @not_operations
end

#operationsArray<Google::Apis::NetworksecurityV1::AuthzPolicyAuthzRuleToRequestOperation>

Optional. Describes properties of one or more targets of a request. At least one of operations or notOperations must be specified. Limited to 1 operation. A match occurs when ANY operation (in operations or notOperations) matches. Within an operation, the match follows AND semantics across fields and OR semantics within a field, i.e. a match occurs when ANY path matches AND ANY header matches and ANY method matches. Corresponds to the JSON property operations



634
635
636
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 634

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



641
642
643
644
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 641

def update!(**args)
  @not_operations = args[:not_operations] if args.key?(:not_operations)
  @operations = args[:operations] if args.key?(:operations)
end