Class: Google::Apis::NetworksecurityV1::AuthzPolicyAuthzRuleToRequestOperationHeaderSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

Describes a set of HTTP headers to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthzPolicyAuthzRuleToRequestOperationHeaderSet

Returns a new instance of AuthzPolicyAuthzRuleToRequestOperationHeaderSet.



725
726
727
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersArray<Google::Apis::NetworksecurityV1::AuthzPolicyAuthzRuleHeaderMatch>

Required. A list of headers to match against in http header. The match can be one of exact, prefix, suffix, or contains (substring match). The match follows AND semantics which means all the headers must match. Matches are always case sensitive unless the ignoreCase is set. Limited to 10 headers per Authorization Policy. Corresponds to the JSON property headers



723
724
725
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 723

def headers
  @headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



730
731
732
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 730

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
end