Class: Google::Apis::NetworksecurityV1::CertificateProviderInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

Specification of a TLS certificate provider instance. Workloads may have one or more CertificateProvider instances (plugins) and one of them is enabled and configured by specifying this message. Workloads use the values from this message to locate and load the CertificateProvider instance configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CertificateProviderInstance

Returns a new instance of CertificateProviderInstance.



1015
1016
1017
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1015

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#plugin_instanceString

Required. Plugin instance name, used to locate and load CertificateProvider instance configuration. Set to "google_cloud_private_spiffe" to use Certificate Authority Service certificate provider instance. Corresponds to the JSON property pluginInstance

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1013

def plugin_instance
  @plugin_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1020
1021
1022
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1020

def update!(**args)
  @plugin_instance = args[:plugin_instance] if args.key?(:plugin_instance)
end