Class: Google::Apis::NetworksecurityV1::DnsThreatDetector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

A DNS threat detector sends DNS query logs to a provider that then analyzes the logs to identify threat events in the DNS queries. By default, all VPC networks in your projects are included. You can exclude specific networks by supplying excluded_networks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsThreatDetector

Returns a new instance of DnsThreatDetector.



1251
1252
1253
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1222
1223
1224
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1222

def create_time
  @create_time
end

#excluded_networksArray<String>

Optional. A list of network resource names which aren't monitored by this DnsThreatDetector. Example: projects/PROJECT_ID/global/networks/NETWORK_NAME. Corresponds to the JSON property excludedNetworks

Returns:

  • (Array<String>)


1228
1229
1230
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1228

def excluded_networks
  @excluded_networks
end

#labelsHash<String,String>

Optional. Any labels associated with the DnsThreatDetector, listed as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1234
1235
1236
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1234

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the DnsThreatDetector resource. Corresponds to the JSON property name

Returns:

  • (String)


1239
1240
1241
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1239

def name
  @name
end

#providerString

Required. The provider used for DNS threat analysis. Corresponds to the JSON property provider

Returns:

  • (String)


1244
1245
1246
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1244

def provider
  @provider
end

#update_timeString

Output only. Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1249
1250
1251
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1249

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1256
1257
1258
1259
1260
1261
1262
1263
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1256

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @excluded_networks = args[:excluded_networks] if args.key?(:excluded_networks)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @update_time = args[:update_time] if args.key?(:update_time)
end