Class: Google::Apis::NetworksecurityV1::InterceptDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

A deployment represents a zonal intercept backend ready to accept GENEVE- encapsulated traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global intercept service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterceptDeployment

Returns a new instance of InterceptDeployment.



2201
2202
2203
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


2145
2146
2147
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2145

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the deployment. Used as additional context for the deployment. Corresponds to the JSON property description

Returns:

  • (String)


2151
2152
2153
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2151

def description
  @description
end

#forwarding_ruleString

Required. Immutable. The regional forwarding rule that fronts the interceptors, for example: projects/123456789/regions/us-central1/forwardingRules/my-rule. See https://google.aip.dev/124. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


2158
2159
2160
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2158

def forwarding_rule
  @forwarding_rule
end

#intercept_deployment_groupString

Required. Immutable. The deployment group that this deployment is a part of, for example: projects/123456789/locations/global/interceptDeploymentGroups/my- dg. See https://google.aip.dev/124. Corresponds to the JSON property interceptDeploymentGroup

Returns:

  • (String)


2165
2166
2167
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2165

def intercept_deployment_group
  @intercept_deployment_group
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2171
2172
2173
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2171

def labels
  @labels
end

#nameString

Immutable. Identifier. The resource name of this deployment, for example: projects/123456789/locations/us-central1-a/interceptDeployments/my-dep. See https://google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


2178
2179
2180
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2178

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. linking a new association to the parent group). See https://google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2186
2187
2188
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2186

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the deployment. See https://google.aip.dev/ 216. Corresponds to the JSON property state

Returns:

  • (String)


2193
2194
2195
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2193

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


2199
2200
2201
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2199

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2206

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @intercept_deployment_group = args[:intercept_deployment_group] if args.key?(:intercept_deployment_group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end