Class: Google::Apis::NetworksecurityV1::InterceptEndpointGroupAssociation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable intercept by itself. To enable intercept, the user must also create a network firewall policy containing intercept rules and associate it with the network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterceptEndpointGroupAssociation

Returns a new instance of InterceptEndpointGroupAssociation.



2532
2533
2534
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2463

def create_time
  @create_time
end

#intercept_endpoint_groupString

Required. Immutable. The endpoint group that this association is connected to, for example: projects/123456789/locations/global/interceptEndpointGroups/my- eg. See https://google.aip.dev/124. Corresponds to the JSON property interceptEndpointGroup

Returns:

  • (String)


2470
2471
2472
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2470

def intercept_endpoint_group
  @intercept_endpoint_group
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2476
2477
2478
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2476

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1::InterceptLocation>

Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group. Corresponds to the JSON property locations



2482
2483
2484
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2482

def locations
  @locations
end

#locations_detailsArray<Google::Apis::NetworksecurityV1::InterceptEndpointGroupAssociationLocationDetails>

Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself. Corresponds to the JSON property locationsDetails



2489
2490
2491
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2489

def locations_details
  @locations_details
end

#nameString

Immutable. Identifier. The resource name of this endpoint group association, for example: projects/123456789/locations/global/ interceptEndpointGroupAssociations/my-eg-association. See https://google.aip. dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


2497
2498
2499
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2497

def name
  @name
end

#networkString

Required. Immutable. The VPC network that is associated. for example: projects/123456789/global/networks/my-network. See https://google.aip.dev/124. Corresponds to the JSON property network

Returns:

  • (String)


2503
2504
2505
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2503

def network
  @network
end

Output only. Identifier used by the data-path. See the NSI GENEVE format for more details: https://docs.cloud.google.com/network-security-integration/docs/ understand-geneve#network_id Corresponds to the JSON property networkCookie

Returns:

  • (Fixnum)


2510
2511
2512
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2510

def network_cookie
  @network_cookie
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


2518
2519
2520
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2518

def reconciling
  @reconciling
end

#stateString

Output only. Current state of the endpoint group association. Corresponds to the JSON property state

Returns:

  • (String)


2524
2525
2526
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2524

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


2530
2531
2532
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2530

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2537

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @intercept_endpoint_group = args[:intercept_endpoint_group] if args.key?(:intercept_endpoint_group)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @locations_details = args[:locations_details] if args.key?(:locations_details)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_cookie = args[:network_cookie] if args.key?(:network_cookie)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end