Class: Google::Apis::NetworksecurityV1::ListBackendAuthenticationConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::ListBackendAuthenticationConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
Response returned by the ListBackendAuthenticationConfigs method.
Instance Attribute Summary collapse
-
#backend_authentication_configs ⇒ Array<Google::Apis::NetworksecurityV1::BackendAuthenticationConfig>
List of BackendAuthenticationConfig resources.
-
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_tokenis included. -
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackendAuthenticationConfigsResponse
constructor
A new instance of ListBackendAuthenticationConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackendAuthenticationConfigsResponse
Returns a new instance of ListBackendAuthenticationConfigsResponse.
2834 2835 2836 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_authentication_configs ⇒ Array<Google::Apis::NetworksecurityV1::BackendAuthenticationConfig>
List of BackendAuthenticationConfig resources.
Corresponds to the JSON property backendAuthenticationConfigs
2820 2821 2822 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2820 def backend_authentication_configs @backend_authentication_configs end |
#next_page_token ⇒ String
If there might be more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this method
again using the value of next_page_token as page_token.
Corresponds to the JSON property nextPageToken
2827 2828 2829 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2827 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2832 2833 2834 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2832 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2839 2840 2841 2842 2843 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 2839 def update!(**args) @backend_authentication_configs = args[:backend_authentication_configs] if args.key?(:backend_authentication_configs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |