Class: Google::Apis::NetworksecurityV1::ListUrlListsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

Response returned by the ListUrlLists method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListUrlListsResponse

Returns a new instance of ListUrlListsResponse.



3440
3441
3442
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If there might be more results than those appearing in this response, then next_page_token is included. To get the next set of results, call this method again using the value of next_page_token as page_token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3428
3429
3430
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3428

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3433
3434
3435
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3433

def unreachable
  @unreachable
end

#url_listsArray<Google::Apis::NetworksecurityV1::UrlList>

List of UrlList resources. Corresponds to the JSON property urlLists



3438
3439
3440
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3438

def url_lists
  @url_lists
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3445
3446
3447
3448
3449
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3445

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @url_lists = args[:url_lists] if args.key?(:url_lists)
end