Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroup

Returns a new instance of MirroringEndpointGroup.



3927
3928
3929
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationDetails>

Output only. List of associations to this endpoint group. Corresponds to the JSON property associations



3860
3861
3862
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3860

def associations
  @associations
end

#connected_deployment_groupsArray<Google::Apis::NetworksecurityV1::MirroringEndpointGroupConnectedDeploymentGroup>

Output only. List of details about the connected deployment groups to this endpoint group. Corresponds to the JSON property connectedDeploymentGroups



3866
3867
3868
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3866

def connected_deployment_groups
  @connected_deployment_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3872
3873
3874
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3872

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group. Corresponds to the JSON property description

Returns:

  • (String)


3878
3879
3880
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3878

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3884
3885
3886
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3884

def labels
  @labels
end

#mirroring_deployment_groupString

Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/ mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124. Corresponds to the JSON property mirroringDeploymentGroup

Returns:

  • (String)


3891
3892
3893
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3891

def mirroring_deployment_group
  @mirroring_deployment_group
end

#nameString

Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https:/ /google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3898
3899
3900
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3898

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3906
3907
3908
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3906

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the endpoint group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


3913
3914
3915
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3913

def state
  @state
end

#typeString

Immutable. The type of the endpoint group. If left unspecified, defaults to DIRECT. Corresponds to the JSON property type

Returns:

  • (String)


3919
3920
3921
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3919

def type
  @type
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3925
3926
3927
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3925

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3932

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @connected_deployment_groups = args[:connected_deployment_groups] if args.key?(:connected_deployment_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end