Class: Google::Apis::NetworksecurityV1::ServerTlsPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

ServerTlsPolicy is a resource that specifies how a server should authenticate incoming requests. This resource itself does not affect configuration unless it is attached to a target HTTPS proxy or endpoint config selector resource. ServerTlsPolicy in the form accepted by Application Load Balancers can be attached only to TargetHttpsProxy with an EXTERNAL, EXTERNAL_MANAGED or INTERNAL_MANAGED load balancing scheme. Traffic Director compatible ServerTlsPolicies can be attached to EndpointPolicy and TargetHttpsProxy with Traffic Director INTERNAL_SELF_MANAGED load balancing scheme.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServerTlsPolicy

Returns a new instance of ServerTlsPolicy.



4731
4732
4733
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4731

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_openBoolean Also known as: allow_open?

This field applies only for Traffic Director policies. It is must be set to false for Application Load Balancer policies. Determines if server allows plaintext connections. If set to true, server allows plain text connections. By default, it is set to false. This setting is not exclusive of other encryption modes. For example, if allow_open and mtls_policy are set, server allows both plain text and mTLS connections. See documentation of other encryption modes to confirm compatibility. Consider using it if you wish to upgrade in place your deployment to TLS while having mixed TLS and non-TLS traffic reaching port :80. Corresponds to the JSON property allowOpen

Returns:

  • (Boolean)


4691
4692
4693
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4691

def allow_open
  @allow_open
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4697
4698
4699
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4697

def create_time
  @create_time
end

#descriptionString

Free-text description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


4702
4703
4704
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4702

def description
  @description
end

#labelsHash<String,String>

Set of label tags associated with the resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4707
4708
4709
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4707

def labels
  @labels
end

#mtls_policyGoogle::Apis::NetworksecurityV1::MtlsPolicy

Specification of the MTLSPolicy. Corresponds to the JSON property mtlsPolicy



4712
4713
4714
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4712

def mtls_policy
  @mtls_policy
end

#nameString

Required. Name of the ServerTlsPolicy resource. It matches the pattern projects/*/locations/location/serverTlsPolicies/server_tls_policy` Corresponds to the JSON propertyname`

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4718

def name
  @name
end

#server_certificateGoogle::Apis::NetworksecurityV1::GoogleCloudNetworksecurityV1CertificateProvider

Specification of certificate provider. Defines the mechanism to obtain the certificate and private key for peer to peer authentication. Corresponds to the JSON property serverCertificate



4724
4725
4726
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4724

def server_certificate
  @server_certificate
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4729
4730
4731
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4729

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4736
4737
4738
4739
4740
4741
4742
4743
4744
4745
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4736

def update!(**args)
  @allow_open = args[:allow_open] if args.key?(:allow_open)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @mtls_policy = args[:mtls_policy] if args.key?(:mtls_policy)
  @name = args[:name] if args.key?(:name)
  @server_certificate = args[:server_certificate] if args.key?(:server_certificate)
  @update_time = args[:update_time] if args.key?(:update_time)
end