Class: Google::Apis::NetworksecurityV1::ThreatOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

Defines what action to take for a specific threat_id match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreatOverride

Returns a new instance of ThreatOverride.



4856
4857
4858
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Required. Threat action override. For some threat types, only a subset of actions applies. Corresponds to the JSON property action

Returns:

  • (String)


4844
4845
4846
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4844

def action
  @action
end

#threat_idString

Required. Vendor-specific ID of a threat to override. Corresponds to the JSON property threatId

Returns:

  • (String)


4849
4850
4851
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4849

def threat_id
  @threat_id
end

#typeString

Output only. Type of the threat (read only). Corresponds to the JSON property type

Returns:

  • (String)


4854
4855
4856
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4854

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4861
4862
4863
4864
4865
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4861

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @threat_id = args[:threat_id] if args.key?(:threat_id)
  @type = args[:type] if args.key?(:type)
end