Class: Google::Apis::NetworksecurityV1::FirewallEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::FirewallEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
Message describing Endpoint object.
Instance Attribute Summary collapse
-
#associated_networks ⇒ Array<String>
Output only.
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1::FirewallEndpointAssociationReference>
Output only.
-
#billing_project_id ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1::FirewallEndpointEndpointSettings
Settings for the endpoint.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallEndpoint
constructor
A new instance of FirewallEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallEndpoint
Returns a new instance of FirewallEndpoint.
1417 1418 1419 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1417 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_networks ⇒ Array<String>
Output only. Deprecated: List of networks that are associated with this
endpoint in the local zone. This is a projection of the
FirewallEndpointAssociations pointing at this endpoint. A network will only
appear in this list after traffic routing is fully configured. Format:
projects/project/global/networks/name.
Corresponds to the JSON property associatedNetworks
1347 1348 1349 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1347 def associated_networks @associated_networks end |
#associations ⇒ Array<Google::Apis::NetworksecurityV1::FirewallEndpointAssociationReference>
Output only. List of FirewallEndpointAssociations that are associated to this
endpoint. An association will only appear in this list after traffic routing
is fully configured.
Corresponds to the JSON property associations
1354 1355 1356 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1354 def associations @associations end |
#billing_project_id ⇒ String
Optional. Project to charge for the deployed firewall endpoint. This field
must be specified when creating the endpoint in the organization scope, and
should be omitted otherwise.
Corresponds to the JSON property billingProjectId
1361 1362 1363 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1361 def billing_project_id @billing_project_id end |
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
1366 1367 1368 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1366 def create_time @create_time end |
#description ⇒ String
Optional. Description of the firewall endpoint. Max length 2048 characters.
Corresponds to the JSON property description
1371 1372 1373 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1371 def description @description end |
#endpoint_settings ⇒ Google::Apis::NetworksecurityV1::FirewallEndpointEndpointSettings
Settings for the endpoint.
Corresponds to the JSON property endpointSettings
1376 1377 1378 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1376 def endpoint_settings @endpoint_settings end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs
Corresponds to the JSON property labels
1381 1382 1383 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1381 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of resource.
Corresponds to the JSON property name
1386 1387 1388 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1386 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. Whether reconciling is in progress, recommended per https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
1392 1393 1394 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1392 def reconciling @reconciling end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
1398 1399 1400 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1398 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
1404 1405 1406 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1404 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. Current state of the endpoint.
Corresponds to the JSON property state
1410 1411 1412 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1410 def state @state end |
#update_time ⇒ String
Output only. Update time stamp
Corresponds to the JSON property updateTime
1415 1416 1417 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1415 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 1422 def update!(**args) @associated_networks = args[:associated_networks] if args.key?(:associated_networks) @associations = args[:associations] if args.key?(:associations) @billing_project_id = args[:billing_project_id] if args.key?(:billing_project_id) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @endpoint_settings = args[:endpoint_settings] if args.key?(:endpoint_settings) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |