Class: Google::Apis::NetworksecurityV1::MirroringDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

A deployment represents a zonal mirroring backend ready to accept GENEVE- encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringDeployment

Returns a new instance of MirroringDeployment.



3689
3690
3691
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3633
3634
3635
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3633

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the deployment. Used as additional context for the deployment. Corresponds to the JSON property description

Returns:

  • (String)


3639
3640
3641
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3639

def description
  @description
end

#forwarding_ruleString

Required. Immutable. The regional forwarding rule that fronts the mirroring collectors, for example: projects/123456789/regions/us-central1/ forwardingRules/my-rule. See https://google.aip.dev/124. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


3646
3647
3648
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3646

def forwarding_rule
  @forwarding_rule
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3652
3653
3654
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3652

def labels
  @labels
end

#mirroring_deployment_groupString

Required. Immutable. The deployment group that this deployment is a part of, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my- dg. See https://google.aip.dev/124. Corresponds to the JSON property mirroringDeploymentGroup

Returns:

  • (String)


3659
3660
3661
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3659

def mirroring_deployment_group
  @mirroring_deployment_group
end

#nameString

Immutable. Identifier. The resource name of this deployment, for example: projects/123456789/locations/us-central1-a/mirroringDeployments/my-dep. See https://google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3666
3667
3668
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3666

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. linking a new association to the parent group). See https://google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3674
3675
3676
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3674

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the deployment. See https://google.aip.dev/ 216. Corresponds to the JSON property state

Returns:

  • (String)


3681
3682
3683
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3681

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3687
3688
3689
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3687

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3694

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @labels = args[:labels] if args.key?(:labels)
  @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end