Class: Google::Apis::NetworksecurityV1::MirroringDeployment
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::MirroringDeployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
A deployment represents a zonal mirroring backend ready to accept GENEVE- encapsulated replica traffic, e.g. a zonal instance group fronted by an internal passthrough load balancer. Deployments are always part of a global deployment group which represents a global mirroring service.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#forwarding_rule ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#mirroring_deployment_group ⇒ String
Required.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringDeployment
constructor
A new instance of MirroringDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringDeployment
Returns a new instance of MirroringDeployment.
3513 3514 3515 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3513 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3457 3458 3459 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3457 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the deployment. Used as additional
context for the deployment.
Corresponds to the JSON property description
3463 3464 3465 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3463 def description @description end |
#forwarding_rule ⇒ String
Required. Immutable. The regional forwarding rule that fronts the mirroring
collectors, for example: projects/123456789/regions/us-central1/
forwardingRules/my-rule. See https://google.aip.dev/124.
Corresponds to the JSON property forwardingRule
3470 3471 3472 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3470 def forwarding_rule @forwarding_rule end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3476 3477 3478 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3476 def labels @labels end |
#mirroring_deployment_group ⇒ String
Required. Immutable. The deployment group that this deployment is a part of,
for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-
dg. See https://google.aip.dev/124.
Corresponds to the JSON property mirroringDeploymentGroup
3483 3484 3485 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3483 def mirroring_deployment_group @mirroring_deployment_group end |
#name ⇒ String
Immutable. Identifier. The resource name of this deployment, for example:
projects/123456789/locations/us-central1-a/mirroringDeployments/my-dep. See
https://google.aip.dev/122 for more details.
Corresponds to the JSON property name
3490 3491 3492 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3490 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This part of the
normal operation (e.g. linking a new association to the parent group). See
https://google.aip.dev/128.
Corresponds to the JSON property reconciling
3498 3499 3500 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3498 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the deployment. See https://google.aip.dev/
216.
Corresponds to the JSON property state
3505 3506 3507 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3505 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3511 3512 3513 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3511 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3518 3519 3520 3521 3522 3523 3524 3525 3526 3527 3528 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3518 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @labels = args[:labels] if args.key?(:labels) @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |