Class: Google::Apis::NetworksecurityV1::MirroringDeploymentGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::MirroringDeploymentGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.
Instance Attribute Summary collapse
-
#connected_endpoint_groups ⇒ Array<Google::Apis::NetworksecurityV1::MirroringDeploymentGroupConnectedEndpointGroup>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::NetworksecurityV1::MirroringLocation>
Output only.
-
#name ⇒ String
Immutable.
-
#nested_deployments ⇒ Array<Google::Apis::NetworksecurityV1::MirroringDeploymentGroupDeployment>
Output only.
-
#network ⇒ String
Required.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringDeploymentGroup
constructor
A new instance of MirroringDeploymentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringDeploymentGroup
Returns a new instance of MirroringDeploymentGroup.
3781 3782 3783 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connected_endpoint_groups ⇒ Array<Google::Apis::NetworksecurityV1::MirroringDeploymentGroupConnectedEndpointGroup>
Output only. The list of endpoint groups that are connected to this resource.
Corresponds to the JSON property connectedEndpointGroups
3716 3717 3718 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3716 def connected_endpoint_groups @connected_endpoint_groups end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3722 3723 3724 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3722 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the deployment group. Used as
additional context for the deployment group.
Corresponds to the JSON property description
3728 3729 3730 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3728 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3734 3735 3736 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3734 def labels @labels end |
#locations ⇒ Array<Google::Apis::NetworksecurityV1::MirroringLocation>
Output only. The list of locations where the deployment group is present.
Corresponds to the JSON property locations
3739 3740 3741 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3739 def locations @locations end |
#name ⇒ String
Immutable. Identifier. The resource name of this deployment group, for example:
projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See
https://google.aip.dev/122 for more details.
Corresponds to the JSON property name
3746 3747 3748 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3746 def name @name end |
#nested_deployments ⇒ Array<Google::Apis::NetworksecurityV1::MirroringDeploymentGroupDeployment>
Output only. The list of Mirroring Deployments that belong to this group.
Corresponds to the JSON property nestedDeployments
3751 3752 3753 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3751 def nested_deployments @nested_deployments end |
#network ⇒ String
Required. Immutable. The network that will be used for all child deployments,
for example: projects/project/global/networks/network`. See https://
google.aip.dev/124.
Corresponds to the JSON propertynetwork`
3758 3759 3760 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3758 def network @network end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This is part of
the normal operation (e.g. adding a new deployment to the group) See https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
3766 3767 3768 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3766 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the deployment group. See https://google.aip.
dev/216.
Corresponds to the JSON property state
3773 3774 3775 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3773 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3779 3780 3781 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3779 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3786 def update!(**args) @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments) @network = args[:network] if args.key?(:network) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |