Class: Google::Apis::NetworksecurityV1::MirroringDeploymentGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

A deployment group aggregates many zonal mirroring backends (deployments) into a single global mirroring service. Consumers can connect this service using an endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringDeploymentGroup

Returns a new instance of MirroringDeploymentGroup.



3605
3606
3607
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_endpoint_groupsArray<Google::Apis::NetworksecurityV1::MirroringDeploymentGroupConnectedEndpointGroup>

Output only. The list of endpoint groups that are connected to this resource. Corresponds to the JSON property connectedEndpointGroups



3540
3541
3542
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3540

def connected_endpoint_groups
  @connected_endpoint_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3546
3547
3548
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3546

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the deployment group. Used as additional context for the deployment group. Corresponds to the JSON property description

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3552

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3558
3559
3560
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3558

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1::MirroringLocation>

Output only. The list of locations where the deployment group is present. Corresponds to the JSON property locations



3563
3564
3565
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3563

def locations
  @locations
end

#nameString

Immutable. Identifier. The resource name of this deployment group, for example: projects/123456789/locations/global/mirroringDeploymentGroups/my-dg. See https://google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3570
3571
3572
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3570

def name
  @name
end

#nested_deploymentsArray<Google::Apis::NetworksecurityV1::MirroringDeploymentGroupDeployment>

Output only. The list of Mirroring Deployments that belong to this group. Corresponds to the JSON property nestedDeployments



3575
3576
3577
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3575

def nested_deployments
  @nested_deployments
end

#networkString

Required. Immutable. The network that will be used for all child deployments, for example: projects/project/global/networks/network`. See https:// google.aip.dev/124. Corresponds to the JSON propertynetwork`

Returns:

  • (String)


3582
3583
3584
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3582

def network
  @network
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new deployment to the group) See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3590
3591
3592
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3590

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the deployment group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


3597
3598
3599
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3597

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3603

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3610

def update!(**args)
  @connected_endpoint_groups = args[:connected_endpoint_groups] if args.key?(:connected_endpoint_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @name = args[:name] if args.key?(:name)
  @nested_deployments = args[:nested_deployments] if args.key?(:nested_deployments)
  @network = args[:network] if args.key?(:network)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end