Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::MirroringEndpointGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationDetails>
Output only.
-
#connected_deployment_groups ⇒ Array<Google::Apis::NetworksecurityV1::MirroringEndpointGroupConnectedDeploymentGroup>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#mirroring_deployment_group ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringEndpointGroup
constructor
A new instance of MirroringEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringEndpointGroup
Returns a new instance of MirroringEndpointGroup.
3842 3843 3844 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3842 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationDetails>
Output only. List of associations to this endpoint group.
Corresponds to the JSON property associations
3775 3776 3777 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3775 def associations @associations end |
#connected_deployment_groups ⇒ Array<Google::Apis::NetworksecurityV1::MirroringEndpointGroupConnectedDeploymentGroup>
Output only. List of details about the connected deployment groups to this
endpoint group.
Corresponds to the JSON property connectedDeploymentGroups
3781 3782 3783 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3781 def connected_deployment_groups @connected_deployment_groups end |
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3787 3788 3789 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3787 def create_time @create_time end |
#description ⇒ String
Optional. User-provided description of the endpoint group. Used as additional
context for the endpoint group.
Corresponds to the JSON property description
3793 3794 3795 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3793 def description @description end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3799 3800 3801 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3799 def labels @labels end |
#mirroring_deployment_group ⇒ String
Immutable. The deployment group that this DIRECT endpoint group is connected
to, for example: projects/123456789/locations/global/
mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124.
Corresponds to the JSON property mirroringDeploymentGroup
3806 3807 3808 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3806 def mirroring_deployment_group @mirroring_deployment_group end |
#name ⇒ String
Immutable. Identifier. The resource name of this endpoint group, for example:
projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https:/
/google.aip.dev/122 for more details.
Corresponds to the JSON property name
3813 3814 3815 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3813 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This is part of
the normal operation (e.g. adding a new association to the group). See https://
google.aip.dev/128.
Corresponds to the JSON property reconciling
3821 3822 3823 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3821 def reconciling @reconciling end |
#state ⇒ String
Output only. The current state of the endpoint group. See https://google.aip.
dev/216.
Corresponds to the JSON property state
3828 3829 3830 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3828 def state @state end |
#type ⇒ String
Immutable. The type of the endpoint group. If left unspecified, defaults to
DIRECT.
Corresponds to the JSON property type
3834 3835 3836 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3834 def type @type end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3840 3841 3842 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3840 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3847 3848 3849 3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3847 def update!(**args) @associations = args[:associations] if args.key?(:associations) @connected_deployment_groups = args[:connected_deployment_groups] if args.key?(:connected_deployment_groups) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |