Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

An endpoint group is a consumer frontend for a deployment group (backend). In order to configure mirroring for a network, consumers must create: - An association between their network and the endpoint group. - A security profile that points to the endpoint group. - A mirroring rule that references the security profile (group).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroup

Returns a new instance of MirroringEndpointGroup.



3750
3751
3752
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationDetails>

Output only. List of associations to this endpoint group. Corresponds to the JSON property associations



3683
3684
3685
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3683

def associations
  @associations
end

#connected_deployment_groupsArray<Google::Apis::NetworksecurityV1::MirroringEndpointGroupConnectedDeploymentGroup>

Output only. List of details about the connected deployment groups to this endpoint group. Corresponds to the JSON property connectedDeploymentGroups



3689
3690
3691
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3689

def connected_deployment_groups
  @connected_deployment_groups
end

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3695
3696
3697
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3695

def create_time
  @create_time
end

#descriptionString

Optional. User-provided description of the endpoint group. Used as additional context for the endpoint group. Corresponds to the JSON property description

Returns:

  • (String)


3701
3702
3703
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3701

def description
  @description
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3707
3708
3709
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3707

def labels
  @labels
end

#mirroring_deployment_groupString

Immutable. The deployment group that this DIRECT endpoint group is connected to, for example: projects/123456789/locations/global/ mirroringDeploymentGroups/my-dg. See https://google.aip.dev/124. Corresponds to the JSON property mirroringDeploymentGroup

Returns:

  • (String)


3714
3715
3716
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3714

def mirroring_deployment_group
  @mirroring_deployment_group
end

#nameString

Immutable. Identifier. The resource name of this endpoint group, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https:/ /google.aip.dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3721
3722
3723
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3721

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This is part of the normal operation (e.g. adding a new association to the group). See https:// google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3729
3730
3731
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3729

def reconciling
  @reconciling
end

#stateString

Output only. The current state of the endpoint group. See https://google.aip. dev/216. Corresponds to the JSON property state

Returns:

  • (String)


3736
3737
3738
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3736

def state
  @state
end

#typeString

Immutable. The type of the endpoint group. If left unspecified, defaults to DIRECT. Corresponds to the JSON property type

Returns:

  • (String)


3742
3743
3744
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3742

def type
  @type
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3748
3749
3750
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3748

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3755
3756
3757
3758
3759
3760
3761
3762
3763
3764
3765
3766
3767
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3755

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @connected_deployment_groups = args[:connected_deployment_groups] if args.key?(:connected_deployment_groups)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @mirroring_deployment_group = args[:mirroring_deployment_group] if args.key?(:mirroring_deployment_group)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end