Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable mirroring by itself. To enable mirroring, the user must also create a network firewall policy containing mirroring rules and associate it with the network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroupAssociation

Returns a new instance of MirroringEndpointGroupAssociation.



3937
3938
3939
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the resource was created. See https://google. aip.dev/148#timestamps. Corresponds to the JSON property createTime

Returns:

  • (String)


3875
3876
3877
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3875

def create_time
  @create_time
end

#labelsHash<String,String>

Optional. Labels are key/value pairs that help to organize and filter resources. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3881
3882
3883
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3881

def labels
  @labels
end

#locationsArray<Google::Apis::NetworksecurityV1::MirroringLocation>

Output only. The list of locations where the association is configured. This information is retrieved from the linked endpoint group. Corresponds to the JSON property locations



3887
3888
3889
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3887

def locations
  @locations
end

#locations_detailsArray<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationLocationDetails>

Output only. The list of locations where the association is present. This information is retrieved from the linked endpoint group, and not configured as part of the association itself. Corresponds to the JSON property locationsDetails



3894
3895
3896
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3894

def locations_details
  @locations_details
end

#mirroring_endpoint_groupString

Immutable. The endpoint group that this association is connected to, for example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg. See https://google.aip.dev/124. Corresponds to the JSON property mirroringEndpointGroup

Returns:

  • (String)


3901
3902
3903
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3901

def mirroring_endpoint_group
  @mirroring_endpoint_group
end

#nameString

Immutable. Identifier. The resource name of this endpoint group association, for example: projects/123456789/locations/global/ mirroringEndpointGroupAssociations/my-eg-association. See https://google.aip. dev/122 for more details. Corresponds to the JSON property name

Returns:

  • (String)


3909
3910
3911
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3909

def name
  @name
end

#networkString

Immutable. The VPC network that is associated. for example: projects/ 123456789/global/networks/my-network. See https://google.aip.dev/124. Corresponds to the JSON property network

Returns:

  • (String)


3915
3916
3917
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3915

def network
  @network
end

#reconcilingBoolean Also known as: reconciling?

Output only. The current state of the resource does not match the user's intended state, and the system is working to reconcile them. This part of the normal operation (e.g. adding a new location to the target deployment group). See https://google.aip.dev/128. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


3923
3924
3925
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3923

def reconciling
  @reconciling
end

#stateString

Output only. Current state of the endpoint group association. Corresponds to the JSON property state

Returns:

  • (String)


3929
3930
3931
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3929

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was most recently updated. See https://google.aip.dev/148#timestamps. Corresponds to the JSON property updateTime

Returns:

  • (String)


3935
3936
3937
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3935

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3942

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @labels = args[:labels] if args.key?(:labels)
  @locations = args[:locations] if args.key?(:locations)
  @locations_details = args[:locations_details] if args.key?(:locations_details)
  @mirroring_endpoint_group = args[:mirroring_endpoint_group] if args.key?(:mirroring_endpoint_group)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end