Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociation
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
An endpoint group association represents a link between a network and an endpoint group in the organization. Creating an association creates the networking infrastructure linking the network to the endpoint group, but does not enable mirroring by itself. To enable mirroring, the user must also create a network firewall policy containing mirroring rules and associate it with the network.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#locations ⇒ Array<Google::Apis::NetworksecurityV1::MirroringLocation>
Output only.
-
#locations_details ⇒ Array<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationLocationDetails>
Output only.
-
#mirroring_endpoint_group ⇒ String
Immutable.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
Immutable.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringEndpointGroupAssociation
constructor
A new instance of MirroringEndpointGroupAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringEndpointGroupAssociation
Returns a new instance of MirroringEndpointGroupAssociation.
3845 3846 3847 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3845 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the resource was created. See https://google.
aip.dev/148#timestamps.
Corresponds to the JSON property createTime
3783 3784 3785 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3783 def create_time @create_time end |
#labels ⇒ Hash<String,String>
Optional. Labels are key/value pairs that help to organize and filter
resources.
Corresponds to the JSON property labels
3789 3790 3791 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3789 def labels @labels end |
#locations ⇒ Array<Google::Apis::NetworksecurityV1::MirroringLocation>
Output only. The list of locations where the association is configured. This
information is retrieved from the linked endpoint group.
Corresponds to the JSON property locations
3795 3796 3797 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3795 def locations @locations end |
#locations_details ⇒ Array<Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationLocationDetails>
Output only. The list of locations where the association is present. This
information is retrieved from the linked endpoint group, and not configured as
part of the association itself.
Corresponds to the JSON property locationsDetails
3802 3803 3804 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3802 def locations_details @locations_details end |
#mirroring_endpoint_group ⇒ String
Immutable. The endpoint group that this association is connected to, for
example: projects/123456789/locations/global/mirroringEndpointGroups/my-eg.
See https://google.aip.dev/124.
Corresponds to the JSON property mirroringEndpointGroup
3809 3810 3811 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3809 def mirroring_endpoint_group @mirroring_endpoint_group end |
#name ⇒ String
Immutable. Identifier. The resource name of this endpoint group association,
for example: projects/123456789/locations/global/
mirroringEndpointGroupAssociations/my-eg-association. See https://google.aip.
dev/122 for more details.
Corresponds to the JSON property name
3817 3818 3819 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3817 def name @name end |
#network ⇒ String
Immutable. The VPC network that is associated. for example: projects/
123456789/global/networks/my-network. See https://google.aip.dev/124.
Corresponds to the JSON property network
3823 3824 3825 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3823 def network @network end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. The current state of the resource does not match the user's
intended state, and the system is working to reconcile them. This part of the
normal operation (e.g. adding a new location to the target deployment group).
See https://google.aip.dev/128.
Corresponds to the JSON property reconciling
3831 3832 3833 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3831 def reconciling @reconciling end |
#state ⇒ String
Output only. Current state of the endpoint group association.
Corresponds to the JSON property state
3837 3838 3839 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3837 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the resource was most recently updated. See
https://google.aip.dev/148#timestamps.
Corresponds to the JSON property updateTime
3843 3844 3845 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3843 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3850 3851 3852 3853 3854 3855 3856 3857 3858 3859 3860 3861 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3850 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @labels = args[:labels] if args.key?(:labels) @locations = args[:locations] if args.key?(:locations) @locations_details = args[:locations_details] if args.key?(:locations_details) @mirroring_endpoint_group = args[:mirroring_endpoint_group] if args.key?(:mirroring_endpoint_group) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @reconciling = args[:reconciling] if args.key?(:reconciling) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |