Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationLocationDetails
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationLocationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
Contains details about the state of an association in a specific cloud location.
Instance Attribute Summary collapse
-
#location ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MirroringEndpointGroupAssociationLocationDetails
constructor
A new instance of MirroringEndpointGroupAssociationLocationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MirroringEndpointGroupAssociationLocationDetails
Returns a new instance of MirroringEndpointGroupAssociationLocationDetails.
4005 4006 4007 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Output only. The cloud location, e.g. "us-central1-a" or "asia-south1".
Corresponds to the JSON property location
3998 3999 4000 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3998 def location @location end |
#state ⇒ String
Output only. The current state of the association in this location.
Corresponds to the JSON property state
4003 4004 4005 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4003 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4010 4011 4012 4013 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4010 def update!(**args) @location = args[:location] if args.key?(:location) @state = args[:state] if args.key?(:state) end |