Class: Google::Apis::NetworksecurityV1::MirroringEndpointGroupAssociationLocationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

Contains details about the state of an association in a specific cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MirroringEndpointGroupAssociationLocationDetails

Returns a new instance of MirroringEndpointGroupAssociationLocationDetails.



3913
3914
3915
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Output only. The cloud location, e.g. "us-central1-a" or "asia-south1". Corresponds to the JSON property location

Returns:

  • (String)


3906
3907
3908
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3906

def location
  @location
end

#stateString

Output only. The current state of the association in this location. Corresponds to the JSON property state

Returns:

  • (String)


3911
3912
3913
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3911

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3918
3919
3920
3921
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3918

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @state = args[:state] if args.key?(:state)
end