Class: Google::Apis::NetworksecurityV1::MtlsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::MtlsPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
Specification of the MTLSPolicy.
Instance Attribute Summary collapse
-
#client_validation_ca ⇒ Array<Google::Apis::NetworksecurityV1::ValidationCa>
Required if the policy is to be used with Traffic Director.
-
#client_validation_mode ⇒ String
When the client presents an invalid certificate or no certificate to the load balancer, the
client_validation_modespecifies how the client connection is handled. -
#client_validation_trust_config ⇒ String
Reference to the TrustConfig from certificatemanager.googleapis.com namespace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MtlsPolicy
constructor
A new instance of MtlsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MtlsPolicy
Returns a new instance of MtlsPolicy.
3610 3611 3612 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_validation_ca ⇒ Array<Google::Apis::NetworksecurityV1::ValidationCa>
Required if the policy is to be used with Traffic Director. For Application
Load Balancers it must be empty. Defines the mechanism to obtain the
Certificate Authority certificate to validate the client certificate.
Corresponds to the JSON property clientValidationCa
3592 3593 3594 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3592 def client_validation_ca @client_validation_ca end |
#client_validation_mode ⇒ String
When the client presents an invalid certificate or no certificate to the load
balancer, the client_validation_mode specifies how the client connection is
handled. Required if the policy is to be used with the Application Load
Balancers. For Traffic Director it must be empty.
Corresponds to the JSON property clientValidationMode
3600 3601 3602 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3600 def client_validation_mode @client_validation_mode end |
#client_validation_trust_config ⇒ String
Reference to the TrustConfig from certificatemanager.googleapis.com namespace.
If specified, the chain validation will be performed against certificates
configured in the given TrustConfig. Allowed only if the policy is to be used
with Application Load Balancers.
Corresponds to the JSON property clientValidationTrustConfig
3608 3609 3610 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3608 def client_validation_trust_config @client_validation_trust_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3615 3616 3617 3618 3619 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 3615 def update!(**args) @client_validation_ca = args[:client_validation_ca] if args.key?(:client_validation_ca) @client_validation_mode = args[:client_validation_mode] if args.key?(:client_validation_mode) @client_validation_trust_config = args[:client_validation_trust_config] if args.key?(:client_validation_trust_config) end |