Class: Google::Apis::NetworksecurityV1::SecurityProfile
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::SecurityProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept).
-
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
-
#type ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfile
constructor
A new instance of SecurityProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfile
Returns a new instance of SecurityProfile.
4559 4560 4561 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4500 4501 4502 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4500 def create_time @create_time end |
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept). It is
used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
Corresponds to the JSON property customInterceptProfile
4506 4507 4508 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4506 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
It is used by mirroring rules with a MIRROR action.
Corresponds to the JSON property customMirroringProfile
4512 4513 4514 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4512 def custom_mirroring_profile @custom_mirroring_profile end |
#description ⇒ String
Optional. An optional description of the profile. Max length 512 characters.
Corresponds to the JSON property description
4517 4518 4519 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4517 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4524 4525 4526 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4524 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4529 4530 4531 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4529 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfile resource. It matches
pattern projects|organizations/*/locations/location/securityProfiles/
security_profile`.
Corresponds to the JSON propertyname`
4536 4537 4538 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4536 def name @name end |
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or
severity levels.
Corresponds to the JSON property threatPreventionProfile
4542 4543 4544 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4542 def threat_prevention_profile @threat_prevention_profile end |
#type ⇒ String
Immutable. The single ProfileType that the SecurityProfile resource configures.
Corresponds to the JSON property type
4547 4548 4549 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4547 def type @type end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4552 4553 4554 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4552 def update_time @update_time end |
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
Corresponds to the JSON property urlFilteringProfile
4557 4558 4559 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4557 def url_filtering_profile @url_filtering_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4564 4565 4566 4567 4568 4569 4570 4571 4572 4573 4574 4575 4576 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4564 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) end |