Class: Google::Apis::NetworksecurityV1::SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfile

Returns a new instance of SecurityProfile.



4551
4552
4553
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4492
4493
4494
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4492

def create_time
  @create_time
end

#custom_intercept_profileGoogle::Apis::NetworksecurityV1::CustomInterceptProfile

CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action. Corresponds to the JSON property customInterceptProfile



4498
4499
4500
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4498

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileGoogle::Apis::NetworksecurityV1::CustomMirroringProfile

CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action. Corresponds to the JSON property customMirroringProfile



4504
4505
4506
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4504

def custom_mirroring_profile
  @custom_mirroring_profile
end

#descriptionString

Optional. An optional description of the profile. Max length 512 characters. Corresponds to the JSON property description

Returns:

  • (String)


4509
4510
4511
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4509

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4516
4517
4518
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4516

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4521
4522
4523
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4521

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfile resource. It matches pattern projects|organizations/*/locations/location/securityProfiles/ security_profile`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4528
4529
4530
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4528

def name
  @name
end

#threat_prevention_profileGoogle::Apis::NetworksecurityV1::ThreatPreventionProfile

ThreatPreventionProfile defines an action for specific threat signatures or severity levels. Corresponds to the JSON property threatPreventionProfile



4534
4535
4536
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4534

def threat_prevention_profile
  @threat_prevention_profile
end

#typeString

Immutable. The single ProfileType that the SecurityProfile resource configures. Corresponds to the JSON property type

Returns:

  • (String)


4539
4540
4541
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4539

def type
  @type
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4544
4545
4546
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4544

def update_time
  @update_time
end

#url_filtering_profileGoogle::Apis::NetworksecurityV1::UrlFilteringProfile

UrlFilteringProfile defines filters based on URL. Corresponds to the JSON property urlFilteringProfile



4549
4550
4551
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4549

def url_filtering_profile
  @url_filtering_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4556
4557
4558
4559
4560
4561
4562
4563
4564
4565
4566
4567
4568
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4556

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
end