Class: Google::Apis::NetworksecurityV1::SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityProfile

Returns a new instance of SecurityProfile.



4230
4231
4232
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Resource creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


4171
4172
4173
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4171

def create_time
  @create_time
end

#custom_intercept_profileGoogle::Apis::NetworksecurityV1::CustomInterceptProfile

CustomInterceptProfile defines in-band integration behavior (intercept). It is used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action. Corresponds to the JSON property customInterceptProfile



4177
4178
4179
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4177

def custom_intercept_profile
  @custom_intercept_profile
end

#custom_mirroring_profileGoogle::Apis::NetworksecurityV1::CustomMirroringProfile

CustomMirroringProfile defines out-of-band integration behavior (mirroring). It is used by mirroring rules with a MIRROR action. Corresponds to the JSON property customMirroringProfile



4183
4184
4185
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4183

def custom_mirroring_profile
  @custom_mirroring_profile
end

#descriptionString

Optional. An optional description of the profile. Max length 512 characters. Corresponds to the JSON property description

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4188

def description
  @description
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4195
4196
4197
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4195

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4200
4201
4202
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4200

def labels
  @labels
end

#nameString

Immutable. Identifier. Name of the SecurityProfile resource. It matches pattern projects|organizations/*/locations/location/securityProfiles/ security_profile`. Corresponds to the JSON propertyname`

Returns:

  • (String)


4207
4208
4209
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4207

def name
  @name
end

#threat_prevention_profileGoogle::Apis::NetworksecurityV1::ThreatPreventionProfile

ThreatPreventionProfile defines an action for specific threat signatures or severity levels. Corresponds to the JSON property threatPreventionProfile



4213
4214
4215
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4213

def threat_prevention_profile
  @threat_prevention_profile
end

#typeString

Immutable. The single ProfileType that the SecurityProfile resource configures. Corresponds to the JSON property type

Returns:

  • (String)


4218
4219
4220
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4218

def type
  @type
end

#update_timeString

Output only. Last resource update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


4223
4224
4225
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4223

def update_time
  @update_time
end

#url_filtering_profileGoogle::Apis::NetworksecurityV1::UrlFilteringProfile

UrlFilteringProfile defines filters based on URL. Corresponds to the JSON property urlFilteringProfile



4228
4229
4230
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4228

def url_filtering_profile
  @url_filtering_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4235

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile)
  @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile)
end