Class: Google::Apis::NetworksecurityV1::SecurityProfile
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::SecurityProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
SecurityProfile is a resource that defines the behavior for one of many ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept).
-
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or severity levels.
-
#type ⇒ String
Immutable.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfile
constructor
A new instance of SecurityProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfile
Returns a new instance of SecurityProfile.
4230 4231 4232 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4171 4172 4173 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4171 def create_time @create_time end |
#custom_intercept_profile ⇒ Google::Apis::NetworksecurityV1::CustomInterceptProfile
CustomInterceptProfile defines in-band integration behavior (intercept). It is
used by firewall rules with an APPLY_SECURITY_PROFILE_GROUP action.
Corresponds to the JSON property customInterceptProfile
4177 4178 4179 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4177 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ Google::Apis::NetworksecurityV1::CustomMirroringProfile
CustomMirroringProfile defines out-of-band integration behavior (mirroring).
It is used by mirroring rules with a MIRROR action.
Corresponds to the JSON property customMirroringProfile
4183 4184 4185 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4183 def custom_mirroring_profile @custom_mirroring_profile end |
#description ⇒ String
Optional. An optional description of the profile. Max length 512 characters.
Corresponds to the JSON property description
4188 4189 4190 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4188 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4195 4196 4197 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4195 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4200 4201 4202 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4200 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfile resource. It matches
pattern projects|organizations/*/locations/location/securityProfiles/
security_profile`.
Corresponds to the JSON propertyname`
4207 4208 4209 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4207 def name @name end |
#threat_prevention_profile ⇒ Google::Apis::NetworksecurityV1::ThreatPreventionProfile
ThreatPreventionProfile defines an action for specific threat signatures or
severity levels.
Corresponds to the JSON property threatPreventionProfile
4213 4214 4215 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4213 def threat_prevention_profile @threat_prevention_profile end |
#type ⇒ String
Immutable. The single ProfileType that the SecurityProfile resource configures.
Corresponds to the JSON property type
4218 4219 4220 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4218 def type @type end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4223 4224 4225 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4223 def update_time @update_time end |
#url_filtering_profile ⇒ Google::Apis::NetworksecurityV1::UrlFilteringProfile
UrlFilteringProfile defines filters based on URL.
Corresponds to the JSON property urlFilteringProfile
4228 4229 4230 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4228 def url_filtering_profile @url_filtering_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4235 4236 4237 4238 4239 4240 4241 4242 4243 4244 4245 4246 4247 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4235 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) end |