Class: Google::Apis::NetworksecurityV1::SecurityProfileGroup
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::SecurityProfileGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
SecurityProfileGroup is a resource that defines the behavior for various ProfileTypes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#custom_intercept_profile ⇒ String
Optional.
-
#custom_mirroring_profile ⇒ String
Optional.
-
#data_path_id ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Immutable.
-
#threat_prevention_profile ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#url_filtering_profile ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityProfileGroup
constructor
A new instance of SecurityProfileGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityProfileGroup
Returns a new instance of SecurityProfileGroup.
4649 4650 4651 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Resource creation timestamp.
Corresponds to the JSON property createTime
4588 4589 4590 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4588 def create_time @create_time end |
#custom_intercept_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomIntercept
configuration.
Corresponds to the JSON property customInterceptProfile
4594 4595 4596 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4594 def custom_intercept_profile @custom_intercept_profile end |
#custom_mirroring_profile ⇒ String
Optional. Reference to a SecurityProfile with the CustomMirroring
configuration.
Corresponds to the JSON property customMirroringProfile
4600 4601 4602 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4600 def custom_mirroring_profile @custom_mirroring_profile end |
#data_path_id ⇒ Fixnum
Output only. Identifier used by the data-path. Unique within container,
location.
Corresponds to the JSON property dataPathId
4606 4607 4608 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4606 def data_path_id @data_path_id end |
#description ⇒ String
Optional. An optional description of the profile group. Max length 2048
characters.
Corresponds to the JSON property description
4612 4613 4614 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4612 def description @description end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4619 4620 4621 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4619 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4624 4625 4626 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4624 def labels @labels end |
#name ⇒ String
Immutable. Identifier. Name of the SecurityProfileGroup resource. It matches
pattern projects|organizations/*/locations/location/securityProfileGroups/
security_profile_group`.
Corresponds to the JSON propertyname`
4631 4632 4633 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4631 def name @name end |
#threat_prevention_profile ⇒ String
Optional. Reference to a SecurityProfile with the ThreatPrevention
configuration.
Corresponds to the JSON property threatPreventionProfile
4637 4638 4639 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4637 def threat_prevention_profile @threat_prevention_profile end |
#update_time ⇒ String
Output only. Last resource update timestamp.
Corresponds to the JSON property updateTime
4642 4643 4644 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4642 def update_time @update_time end |
#url_filtering_profile ⇒ String
Optional. Reference to a SecurityProfile with the UrlFiltering configuration.
Corresponds to the JSON property urlFilteringProfile
4647 4648 4649 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4647 def url_filtering_profile @url_filtering_profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4654 4655 4656 4657 4658 4659 4660 4661 4662 4663 4664 4665 4666 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4654 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom_intercept_profile = args[:custom_intercept_profile] if args.key?(:custom_intercept_profile) @custom_mirroring_profile = args[:custom_mirroring_profile] if args.key?(:custom_mirroring_profile) @data_path_id = args[:data_path_id] if args.key?(:data_path_id) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @threat_prevention_profile = args[:threat_prevention_profile] if args.key?(:threat_prevention_profile) @update_time = args[:update_time] if args.key?(:update_time) @url_filtering_profile = args[:url_filtering_profile] if args.key?(:url_filtering_profile) end |