Class: Google::Apis::NetworksecurityV1::ServerTlsPolicy
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::ServerTlsPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
ServerTlsPolicy is a resource that specifies how a server should authenticate
incoming requests. This resource itself does not affect configuration unless
it is attached to a target HTTPS proxy or endpoint config selector resource.
ServerTlsPolicy in the form accepted by Application Load Balancers can be
attached only to TargetHttpsProxy with an EXTERNAL, EXTERNAL_MANAGED or
INTERNAL_MANAGED load balancing scheme. Traffic Director compatible
ServerTlsPolicies can be attached to EndpointPolicy and TargetHttpsProxy with
Traffic Director INTERNAL_SELF_MANAGED load balancing scheme.
Instance Attribute Summary collapse
-
#allow_open ⇒ Boolean
(also: #allow_open?)
This field applies only for Traffic Director policies.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Free-text description of the resource.
-
#labels ⇒ Hash<String,String>
Set of label tags associated with the resource.
-
#mtls_policy ⇒ Google::Apis::NetworksecurityV1::MtlsPolicy
Specification of the MTLSPolicy.
-
#name ⇒ String
Required.
-
#server_certificate ⇒ Google::Apis::NetworksecurityV1::GoogleCloudNetworksecurityV1CertificateProvider
Specification of certificate provider.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServerTlsPolicy
constructor
A new instance of ServerTlsPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServerTlsPolicy
Returns a new instance of ServerTlsPolicy.
4730 4731 4732 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_open ⇒ Boolean Also known as: allow_open?
This field applies only for Traffic Director policies. It is must be set to
false for Application Load Balancer policies. Determines if server allows
plaintext connections. If set to true, server allows plain text connections.
By default, it is set to false. This setting is not exclusive of other
encryption modes. For example, if allow_open and mtls_policy are set,
server allows both plain text and mTLS connections. See documentation of other
encryption modes to confirm compatibility. Consider using it if you wish to
upgrade in place your deployment to TLS while having mixed TLS and non-TLS
traffic reaching port :80.
Corresponds to the JSON property allowOpen
4690 4691 4692 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4690 def allow_open @allow_open end |
#create_time ⇒ String
Output only. The timestamp when the resource was created.
Corresponds to the JSON property createTime
4696 4697 4698 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4696 def create_time @create_time end |
#description ⇒ String
Free-text description of the resource.
Corresponds to the JSON property description
4701 4702 4703 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4701 def description @description end |
#labels ⇒ Hash<String,String>
Set of label tags associated with the resource.
Corresponds to the JSON property labels
4706 4707 4708 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4706 def labels @labels end |
#mtls_policy ⇒ Google::Apis::NetworksecurityV1::MtlsPolicy
Specification of the MTLSPolicy.
Corresponds to the JSON property mtlsPolicy
4711 4712 4713 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4711 def mtls_policy @mtls_policy end |
#name ⇒ String
Required. Name of the ServerTlsPolicy resource. It matches the pattern
projects/*/locations/location/serverTlsPolicies/server_tls_policy`
Corresponds to the JSON propertyname`
4717 4718 4719 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4717 def name @name end |
#server_certificate ⇒ Google::Apis::NetworksecurityV1::GoogleCloudNetworksecurityV1CertificateProvider
Specification of certificate provider. Defines the mechanism to obtain the
certificate and private key for peer to peer authentication.
Corresponds to the JSON property serverCertificate
4723 4724 4725 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4723 def server_certificate @server_certificate end |
#update_time ⇒ String
Output only. The timestamp when the resource was updated.
Corresponds to the JSON property updateTime
4728 4729 4730 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4728 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4735 def update!(**args) @allow_open = args[:allow_open] if args.key?(:allow_open) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @mtls_policy = args[:mtls_policy] if args.key?(:mtls_policy) @name = args[:name] if args.key?(:name) @server_certificate = args[:server_certificate] if args.key?(:server_certificate) @update_time = args[:update_time] if args.key?(:update_time) end |