Class: Google::Apis::NetworksecurityV1::Source
- Inherits:
-
Object
- Object
- Google::Apis::NetworksecurityV1::Source
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb
Overview
Specification of traffic source attributes.
Instance Attribute Summary collapse
-
#ip_blocks ⇒ Array<String>
Optional.
-
#principals ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Source
constructor
A new instance of Source.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Source
Returns a new instance of Source.
4558 4559 4560 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_blocks ⇒ Array<String>
Optional. List of CIDR ranges to match based on source IP address. At least
one IP block should match. Single IP (e.g., "1.2.3.4") and CIDR (e.g., "1.2.3.
0/24") are supported. Authorization based on source IP alone should be avoided.
The IP addresses of any load balancers or proxies should be considered
untrusted.
Corresponds to the JSON property ipBlocks
4546 4547 4548 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4546 def ip_blocks @ip_blocks end |
#principals ⇒ Array<String>
Optional. List of peer identities to match for authorization. At least one
principal should match. Each peer can be an exact match, or a prefix match (
example, "namespace/") or a suffix match (example, "/service-account") or a
presence match "*". Authorization based on the principal name without
certificate validation (configured by ServerTlsPolicy resource) is considered
insecure.
Corresponds to the JSON property principals
4556 4557 4558 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4556 def principals @principals end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4563 4564 4565 4566 |
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4563 def update!(**args) @ip_blocks = args[:ip_blocks] if args.key?(:ip_blocks) @principals = args[:principals] if args.key?(:principals) end |