Class: Google::Apis::NetworksecurityV1::ThreatPreventionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

ThreatPreventionProfile defines an action for specific threat signatures or severity levels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThreatPreventionProfile

Returns a new instance of ThreatPreventionProfile.



4570
4571
4572
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#antivirus_overridesArray<Google::Apis::NetworksecurityV1::AntivirusOverride>

Optional. Configuration for overriding antivirus actions per protocol. Corresponds to the JSON property antivirusOverrides



4556
4557
4558
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4556

def antivirus_overrides
  @antivirus_overrides
end

#severity_overridesArray<Google::Apis::NetworksecurityV1::SeverityOverride>

Optional. Configuration for overriding threats actions by severity match. Corresponds to the JSON property severityOverrides



4561
4562
4563
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4561

def severity_overrides
  @severity_overrides
end

#threat_overridesArray<Google::Apis::NetworksecurityV1::ThreatOverride>

Optional. Configuration for overriding threats actions by threat_id match. If a threat is matched both by configuration provided in severity_overrides and threat_overrides, the threat_overrides action is applied. Corresponds to the JSON property threatOverrides



4568
4569
4570
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4568

def threat_overrides
  @threat_overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4575
4576
4577
4578
4579
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4575

def update!(**args)
  @antivirus_overrides = args[:antivirus_overrides] if args.key?(:antivirus_overrides)
  @severity_overrides = args[:severity_overrides] if args.key?(:severity_overrides)
  @threat_overrides = args[:threat_overrides] if args.key?(:threat_overrides)
end