Class: Google::Apis::NetworksecurityV1::TlsInspectionPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networksecurity_v1/classes.rb,
lib/google/apis/networksecurity_v1/representations.rb,
lib/google/apis/networksecurity_v1/representations.rb

Overview

The TlsInspectionPolicy resource contains references to CA pools in Certificate Authority Service and associated metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TlsInspectionPolicy

Returns a new instance of TlsInspectionPolicy.



4990
4991
4992
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4990

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_poolString

Required. A CA pool resource used to issue interception certificates. The CA pool string has a relative resource path following the form "projects/project /locations/location/caPools/ca_pool". Corresponds to the JSON property caPool

Returns:

  • (String)


4913
4914
4915
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4913

def ca_pool
  @ca_pool
end

#create_timeString

Output only. The timestamp when the resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4918
4919
4920
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4918

def create_time
  @create_time
end

#custom_tls_featuresArray<String>

Optional. List of custom TLS cipher suites selected. This field is valid only if the selected tls_feature_profile is CUSTOM. The compute.SslPoliciesService. ListAvailableFeatures method returns the set of features that can be specified in this list. Note that Secure Web Proxy does not yet honor this field. Corresponds to the JSON property customTlsFeatures

Returns:

  • (Array<String>)


4926
4927
4928
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4926

def custom_tls_features
  @custom_tls_features
end

#descriptionString

Optional. Free-text description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


4931
4932
4933
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4931

def description
  @description
end

#exclude_public_ca_setBoolean Also known as: exclude_public_ca_set?

Optional. If FALSE (the default), use our default set of public CAs in addition to any CAs specified in trust_config. These public CAs are currently based on the Mozilla Root Program and are subject to change over time. If TRUE, do not accept our default set of public CAs. Only CAs specified in trust_config will be accepted. This defaults to FALSE (use public CAs in addition to trust_config) for backwards compatibility, but trusting public root CAs is not recommended unless the traffic in question is outbound to public web servers. When possible, prefer setting this to "false" and explicitly specifying trusted CAs and certificates in a TrustConfig. Note that Secure Web Proxy does not yet honor this field. Corresponds to the JSON property excludePublicCaSet

Returns:

  • (Boolean)


4945
4946
4947
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4945

def exclude_public_ca_set
  @exclude_public_ca_set
end

#min_tls_versionString

Optional. Minimum TLS version that the firewall should use when negotiating connections with both clients and servers. If this is not set, then the default value is to allow the broadest set of clients and servers (TLS 1.0 or higher). Setting this to more restrictive values may improve security, but may also prevent the firewall from connecting to some clients or servers. Note that Secure Web Proxy does not yet honor this field. Corresponds to the JSON property minTlsVersion

Returns:

  • (String)


4956
4957
4958
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4956

def min_tls_version
  @min_tls_version
end

#nameString

Required. Name of the resource. Name is of the form projects/project/ locations/location/tlsInspectionPolicies/tls_inspection_policy tls_inspection_policy should match the pattern:(^a-z ?$). Corresponds to the JSON property name

Returns:

  • (String)


4964
4965
4966
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4964

def name
  @name
end

#tls_feature_profileString

Optional. The selected Profile. If this is not set, then the default value is to allow the broadest set of clients and servers ("PROFILE_COMPATIBLE"). Setting this to more restrictive values may improve security, but may also prevent the TLS inspection proxy from connecting to some clients or servers. Note that Secure Web Proxy does not yet honor this field. Corresponds to the JSON property tlsFeatureProfile

Returns:

  • (String)


4973
4974
4975
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4973

def tls_feature_profile
  @tls_feature_profile
end

#trust_configString

Optional. A TrustConfig resource used when making a connection to the TLS server. This is a relative resource path following the form "projects/project /locations/location/trustConfigs/trust_config". This is necessary to intercept TLS connections to servers with certificates signed by a private CA or self-signed certificates. Note that Secure Web Proxy does not yet honor this field. Corresponds to the JSON property trustConfig

Returns:

  • (String)


4983
4984
4985
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4983

def trust_config
  @trust_config
end

#update_timeString

Output only. The timestamp when the resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4988
4989
4990
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4988

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4995
4996
4997
4998
4999
5000
5001
5002
5003
5004
5005
5006
# File 'lib/google/apis/networksecurity_v1/classes.rb', line 4995

def update!(**args)
  @ca_pool = args[:ca_pool] if args.key?(:ca_pool)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom_tls_features = args[:custom_tls_features] if args.key?(:custom_tls_features)
  @description = args[:description] if args.key?(:description)
  @exclude_public_ca_set = args[:exclude_public_ca_set] if args.key?(:exclude_public_ca_set)
  @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version)
  @name = args[:name] if args.key?(:name)
  @tls_feature_profile = args[:tls_feature_profile] if args.key?(:tls_feature_profile)
  @trust_config = args[:trust_config] if args.key?(:trust_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end